@@ -6,10 +6,10 @@ import (
 
 func init() {
 	release := Release{
-		Version: "0.29.0",
+		Version: "0.23.0",
 		Containers: []cnao.Container{
 			cnao.Container{
-				ParentName: "multus",
+				ParentName: "kube-multus-ds-amd64",
 				ParentKind: "DaemonSet",
 				Name:       "kube-multus",
 				Image:      "quay.io/kubevirt/cluster-network-addon-multus:v3.2.0-1.gitbf61002",
@@ -30,31 +30,25 @@ func init() {
 				ParentName: "kubemacpool-mac-controller-manager",
 				ParentKind: "Deployment",
 				Name:       "manager",
-				Image:      "quay.io/kubevirt/kubemacpool:v0.8.2",
+				Image:      "quay.io/kubevirt/kubemacpool:v0.8.0",
 			},
 			cnao.Container{
 				ParentName: "nmstate-handler",
 				ParentKind: "DaemonSet",
 				Name:       "nmstate-handler",
-				Image:      "quay.io/nmstate/kubernetes-nmstate-handler:v0.14.0",
-			},
-			cnao.Container{
-				ParentName: "nmstate-handler-worker",
-				ParentKind: "DaemonSet",
-				Name:       "nmstate-handler",
-				Image:      "quay.io/nmstate/kubernetes-nmstate-handler:v0.14.0",
+				Image:      "quay.io/nmstate/kubernetes-nmstate-handler:v0.12.0",
 			},
 			cnao.Container{
 				ParentName: "ovs-cni-amd64",
 				ParentKind: "DaemonSet",
 				Name:       "ovs-cni-plugin",
-				Image:      "quay.io/kubevirt/ovs-cni-plugin:v0.10.0",
+				Image:      "quay.io/kubevirt/ovs-cni-plugin:v0.8.0",
 			},
 			cnao.Container{
 				ParentName: "ovs-cni-amd64",
 				ParentKind: "DaemonSet",
 				Name:       "ovs-cni-marker",
-				Image:      "quay.io/kubevirt/ovs-cni-marker:v0.10.0",
+				Image:      "quay.io/kubevirt/ovs-cni-marker:v0.8.0",
 			},
 		},
 		SupportedSpec: cnao.NetworkAddonsConfigSpec{
